@@ -1,5 +1,4 @@
 var view = require('../../lib/view');
-var clone = require('clone');
 var page = require('page');
 var auth = require('../../lib/auth');
 
@@ -30,24 +29,16 @@ module.exports = view.extend({
         },
         clean: function (e) {
             var self = this;
-            var sh = self.model._fs.Shell();
-            var fs = self.model._fs;
-            var sync = fs.sync;
 
-            function onClear(err) {
-                sync.request();
-                page('/sign-in');
-            }
-
-            fs.stat('/', function(e, stat) {
-                if (!stat.isDirectory()) {
-                    fs.unlink('/', onClear);
-                } else {
-                    sh.rm('/', {
-                        recursive: true
-                    }, onClear);
+            var username = this.model.data.user.username;
+            this.model.data.apps.forEach(function (app, index) {
+                if(app.author.username === username) {
+                    delete self.model.data.apps[index];
                 }
             });
+            self.model.save(function() {
+                page('/sign-in');
+            });
         }
     }
 });
